$(function () {
    let client = ZAFClient.init();
    client.invoke('resize', {width: '316px', height: '650px'});
    client.get('ticket.requester').then(
        function (data) {
            let requester = data['ticket.requester'];

            loginWesupply(client, requester.email);
        },
        showError
    );
});

function loginWesupply(client, customerEmail) {
    let formBody = 'user=' + encodeURIComponent(customerEmail) + '&type=apiorder';

    client.metadata()
    .then(extractData)
    .then(function (data) {
        const WSuri = 'https://' + decodeURIComponent(data.dUri);
        const encrypted = encryptData(customerEmail, data.enc);

        let settings = {
            url: WSuri + '/account/apiorders',
            headers: {"Authorization": encrypted},
            type: 'POST',
            content_type: 'application/x-www-form-urlencoded',
            data: formBody,
            cors: true
        };
        client.request(settings).then(
            function (tk) {
                showInfo(customerEmail, tk, data.dUri);
            },
            showError
        );
    });
}

function showInfo(email, encrypted, dUri) {
    let requester_data = {
        'iframeSrc': 'https://'+dUri+'/?t\x6Fk\x65n\='+encrypted+'&apid='+email,
    };
    const source = $("#requester-template").html();
    const html = Handlebars.compile(source)(requester_data);

    $("#content").html(html);
}

function showError(response) {
    let error_data = {
        'status': response.status,
        'statusText': response.statusText,
        'responseText': stripHtml(response.responseText)
    };
    const source = $("#error-template").html();
    const html = Handlebars.compile(source)(error_data);

    $("#loading-spinner").remove();
    $("#content").html(html);
}

function stripHtml(html) {
    let temporalDivElement = document.createElement("div");
    temporalDivElement.innerHTML = html;
    return temporalDivElement.textContent || temporalDivElement.innerText || "";
}

function extractData(metaInfo) {
    return {
        dUri: metaInfo.settings.WesupplyDomain,
        enc: metaInfo.settings.WesupplyEncryption
    };
}

function encryptData(mainWord, extraWord) {
    const hash = CryptoJS.SHA3(
        mainWord, extraWord
    );
    const hashInBase64 = CryptoJS.enc.Base64.stringify(hash);
    return CryptoJS.AES.encrypt(hashInBase64, extraWord).toString();
}
